#!/bin/bash

# arg 1: absolute path of picture folder to create dynamic wallpaper
# optional arg 2: duration of a picture change to another picture (minute)

################################################################################
# this script can generate dynamic wallpaper xml file in Ubuntu linux
#
# enable ns-script by putting the following file into ns-script folder
#=========================GenerateDynamicWallpaperXML=============================
#	#!/bin/bash
#	OLDIFS=$IFS;
#	IFS=$'\n';
#	for path in $NAUTILUS_SCRIPT_SELECTED_FILE_PATHS
#	do
#		gnome-terminal -x {modify here: absulute path of the script}/dynamic-wallpaper-xml-generater.sh $path &
#		break;
#	done
#	IFS=$OLDIFS;
#===============================================================================
################################################################################

################################################################################
# parameter process

if [ $# -lt 1 ] || [ $# -gt 2 ]; then
	echo "usage:";
	echo " arg 1: absolute path of picture folder to create dynamic wallpaper";
	echo " optional arg 2: duration of a picture change to another picture (minute)";
	read -p " press enter to exit ...";
	exit 0;
fi

directory=$1

if [ "${directory#/}" == "${directory}" ]; then
	echo "error: not absolute path!";
	read -p " press enter to exit ...";
	exit 0;
elif [ ! -d "$directory" ]; then 
	echo "error: not a path!";
	read -p " press enter to exit ...";
	exit 0;
fi

foldername=`echo $directory | awk -F "/" '{print $NF}'`;
xmlfile=$foldername.xml;

if [ $# -eq 2 ]; then
	duration=$2;
else
	read -p "enter the duration time(minute) of a wallpaper picture: " duration;
fi

############################################################
# algorithm

OLDIFS=$IFS;
IFS=$'\n';

cd $directory
rm -f $xmlfile

pictures=`ls`

count=0
for picture in $pictures
do
	if [ ! -d "$picture" ]; then
		arrPicture[$count]=$picture
		let count++
	fi
done

echo "<!-- Generated by dynamic-wallpaper-xml-generater.sh -->">> $xmlfile
echo "<background>">> $xmlfile
echo "  <starttime>">> $xmlfile
echo "    <year>1989</year>">> $xmlfile
echo "    <month>05</month>">> $xmlfile
echo "    <day>11</day>">> $xmlfile
echo "    <hour>00</hour>">> $xmlfile
echo "    <minute>00</minute>">> $xmlfile
echo "    <second>00</second>">> $xmlfile
echo "  </starttime>">> $xmlfile
echo "<!-- This animation will start at midnight. -->">> $xmlfile

i=0
while [ $i -lt $[$count-1] ]
do
	echo "  <static>">> $xmlfile
	echo "    <duration>"$[$duration*60-5]".0</duration>">> $xmlfile
	echo "    <file>"$directory/${arrPicture[$i]}"</file>">> $xmlfile
	echo "  </static>">> $xmlfile
	echo "  <transition>">> $xmlfile
	echo "    <duration>5.0</duration>">> $xmlfile
	echo "    <from>"$directory/${arrPicture[$i]}"</from>">> $xmlfile
	echo "    <to>"$directory/${arrPicture[$[$i+1]]}"</to>">> $xmlfile
	echo "  </transition>">> $xmlfile
	
	let i++
done

echo "  <static>">> $xmlfile
echo "    <duration>"$[$duration*60-5]".0</duration>">> $xmlfile
echo "    <file>"$directory/${arrPicture[$[$count-1]]}"</file>">> $xmlfile
echo "  </static>">> $xmlfile
echo "  <transition>">> $xmlfile
echo "    <duration>5.0</duration>">> $xmlfile
echo "    <from>"$directory/${arrPicture[$[$count-1]]}"</from>">> $xmlfile
echo "    <to>"$directory/${arrPicture[0]}"</to>">> $xmlfile
echo "  </transition>">> $xmlfile
echo "</background>">> $xmlfile

gsettings set org.gnome.desktop.background picture-uri 'file://'$directory'/'$xmlfile

IFS=$OLDIFS;
